export interface ExcueteParams<T extends any[] = any, K = any> {
    fn: (...params: T) => Promise<K>;
    params: T;
    resolve: (value: unknown) => void;
    reject: (reason?: any) => void;
}
export declare type CompletedHook = (() => void) | null;
export interface QueueOptions {
    /**
     * 是否自动执行
     * @desc 默认为true, 队列新增排队成员时会自动执行; 若设置为false, 需要手动调用run方法执行队列
     * @default true
     */
    auto?: boolean;
    /**
     * 并发数量
     * @default {number} 3
     */
    concurrencyCount?: number;
}
export declare class Queue {
    #private;
    /**
     * 创建一个异步执行队列
     */
    constructor(options?: QueueOptions);
    /**
     * 队列长度
     */
    get length(): number;
    /**
     * 设置队列的并发数量
     * @param {number} count 并发数量
     */
    setConcurrencyCount: (count: number) => this;
    /**
     * 队列执行完毕时的钩子
     */
    setCompletedHook: (hook: CompletedHook) => this;
    /**
     * 切换执行模式: 自动/手动
     */
    toggleMode(auto?: boolean): this;
    /**
     * 当前是否是自动执行队列
     */
    isAuto: () => boolean;
    /**
     * 将异步函数推入队列
     */
    push: <T extends any[] = any, K = any>(fn: (...params: T) => Promise<K>, ...params: T) => Promise<unknown>;
    /**
     * 手动启动队列
     */
    run: () => void;
}
